==> blender-2.31.tar.gz: blender-2.31/source/blender/writestreamglue/stub/BLO_keyStoreSTUB.c <==
/**
 * $Id: BLO_keyStoreSTUB.c,v 1.4 2003/05/30 15:06:51 sirdude Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 * keyStore stubs
 */

#include <stdio.h>

#include "BLO_keyStore.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

	void
keyStoreConstructor(
	UserStruct *keyUserStruct,
	char *privHexKey,
	char *pubHexKey,
	unsigned char *ByteChecks,
	char *HexPython)
{
	keyUserStruct = NULL;
	privHexKey = NULL;
	pubHexKey = NULL;
	ByteChecks = NULL;
	HexPython = NULL;
}

	void
keyStoreDestructor(
	void)
{
}

==> blender-2.32.tar.gz: blender-2.32/source/blender/writestreamglue/stub/BLO_keyStoreSTUB.c <==
/**
 * $Id: BLO_keyStoreSTUB.c,v 1.5 2004/01/03 03:11:22 zuster Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 * keyStore stubs
 */

#include <stdio.h>

#include "BLO_keyStore.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

	void
keyStoreConstructor(
	struct UserStruct *keyUserStruct,
	char *privHexKey,
	char *pubHexKey,
	unsigned char *ByteChecks,
	char *HexPython)
{
	keyUserStruct = NULL;
	privHexKey = NULL;
	pubHexKey = NULL;
	ByteChecks = NULL;
	HexPython = NULL;
}

	void
keyStoreDestructor(
	void)
{
}
